==> image-loader-2.5.0-sources.jar: com/budiyev/android/imageloader/CacheImageAction.java <==
/*
 * MIT License
 *
 * Copyright (c) 2018 Yuriy Budiyev [yuriy.budiyev@yandex.ru]
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.budiyev.android.imageloader;

import java.lang.ref.WeakReference;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Future;

import android.graphics.Bitmap;
import android.support.annotation.NonNull;

final class CacheImageAction implements Callable<Void> {
    private final String mKey;
    private final WeakReference<Bitmap> mImage;
    private final ImageCache mCache;
    private volatile Future<?> mFuture;
    private volatile boolean mCancelled;

    public CacheImageAction(@NonNull String key, @NonNull Bitmap image, @NonNull ImageCache cache) {
        mKey = key;
        mImage = new WeakReference<>(image);
        mCache = cache;
    }

    @NonNull
    public CacheImageAction submit(@NonNull ExecutorService executor) {
        mFuture = executor.submit(this);
        return this;
    }

    public void cancel() {
        mCancelled = true;
        mFuture.cancel(true);
        mImage.clear();
    }

    @Override
    public Void call() throws Exception {
        if (!mCancelled) {
            Bitmap image = mImage.get();
            if (image != null) {
                mCache.put(mKey, image);
            }
        }
        return null;
    }
}

==> image-loader-2.5.5-sources.jar: com/budiyev/android/imageloader/CacheImageAction.java <==
/*
 * MIT License
 *
 * Copyright (c) 2018 Yuriy Budiyev [yuriy.budiyev@yandex.ru]
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.budiyev.android.imageloader;

import java.lang.ref.WeakReference;

import android.graphics.Bitmap;
import android.support.annotation.NonNull;

final class CacheImageAction extends ImageRequestAction {
    private final String mKey;
    private final WeakReference<Bitmap> mImage;
    private final ImageCache mCache;

    public CacheImageAction(@NonNull String key, @NonNull Bitmap image, @NonNull ImageCache cache) {
        mKey = key;
        mImage = new WeakReference<>(image);
        mCache = cache;
    }

    @Override
    protected void execute() {
        if (!isCancelled()) {
            Bitmap image = mImage.get();
            if (image != null) {
                mCache.put(mKey, image);
            }
        }
    }

    @Override
    protected void onCancelled() {
        mImage.clear();
    }
}
